@@ -418,6 +418,8 @@ TEST_F(ImageTest, ConvertPixelFormat)
          Image::ConvertPixelFormat("RGBA_INT8"));
   EXPECT_EQ(Image::PixelFormatType::RGB_INT16,
          Image::ConvertPixelFormat("RGB_INT16"));
+  EXPECT_EQ(Image::PixelFormatType::RGBA_INT16,
+         Image::ConvertPixelFormat("RGBA_INT16"));
   EXPECT_EQ(Image::PixelFormatType::RGB_INT32,
          Image::ConvertPixelFormat("RGB_INT32"));
   EXPECT_EQ(Image::PixelFormatType::BGR_INT8,
@@ -720,6 +722,7 @@ TEST_F(ImageTest, Color16bit)
     EXPECT_EQ(height, img.Height());
     EXPECT_EQ(bpp, img.BPP());
     EXPECT_EQ(width * bpp / 8u, img.Pitch());
+    EXPECT_EQ(common::Image::PixelFormatType::RGBA_INT16, img.PixelFormat());
     math::Color maxColor(0.0f, 0.0f, 0.847f, 0.5f);
     EXPECT_NEAR(maxColor.R(), img.MaxColor().R(), 1e-3);
     EXPECT_NEAR(maxColor.G(), img.MaxColor().G(), 1e-3);
