@@ -28,6 +28,7 @@
 #include "gz/common/Console.hh"
 #include "gz/common/StringUtils.hh"
 #include "gz/common/SystemPaths.hh"
+#include "gz/common/URI.hh"
 #include "gz/common/Util.hh"
 
 using namespace gz;
@@ -530,6 +531,12 @@ void SystemPaths::AddFindFileCallback(
   this->dataPtr->findFileCbs.push_back(_cb);
 }
 
+/////////////////////////////////////////////////
+void SystemPaths::ClearFindFileCallbacks()
+{
+  this->dataPtr->findFileCbs.clear();
+}
+
 /////////////////////////////////////////////////
 void SystemPaths::AddFindFileURICallback(
     SystemPaths::Implementation::FindURIFunction _cb)
@@ -537,6 +544,12 @@ void SystemPaths::AddFindFileURICallback(
   this->dataPtr->findFileURICbs.push_back(_cb);
 }
 
+/////////////////////////////////////////////////
+void SystemPaths::ClearFindFileURICallbacks()
+{
+  this->dataPtr->findFileURICbs.clear();
+}
+
 /////////////////////////////////////////////////
 std::list<std::string> SystemPaths::PathsFromEnv(const std::string &_env)
 {
